Error types used by azathoth utilities.
This module is always available and provides error enums and aliases shared by other feature-gated modules in this crate.
Enums
Type Aliases
- AzUtil
Result - Result wrapper
Error types used by azathoth utilities.
This module is always available and provides error enums and aliases shared by other feature-gated modules in this crate.