format_rt

Function format_rt 

pub fn format_rt<W, A>(buf: &mut W, fmt: &str, args: &A) -> AzUtilResult<()>
where W: WriteBuffer, A: FormatArgs,
String formatting function

Accepts a mutable buffer that implements the WriteBuffer trait, a format string, and any type of argument that implements the FormatArgs trait Writes the formatted value to the buffer.