pub struct FormatSpec { /* private fields */ }Expand description
Format specifier struct
Used to track the format specifiers in a string
Implementations
Sourceimpl FormatSpec
impl FormatSpec
Sourcepub fn parse_spec(s: &str) -> Self
pub fn parse_spec(s: &str) -> Self
Parses a string for extended format specifiers
This function may be extended in the future, but for now it only searches for : and # chars