FormatArgs

Trait FormatArgs 

pub trait FormatArgs {
    // Required method
    fn format_at<W: WriteBuffer>(
        &self,
        index: usize,
        w: &mut W,
        spec: &FormatSpec,
    ) -> AzUtilResult<()>;
}
Argument formatting trait

The trait requires each implementor to implement the FormatArgs::format_at function

Required Methods

fn format_at<W: WriteBuffer>( &self, index: usize, w: &mut W, spec: &FormatSpec, ) -> AzUtilResult<()>

Argument formatting function

Expects a writable buffer that implements the WriteBuffer trait, an index for specifying where to place the formatted value, and a FormatSpec object to allow the usage of the additional format specifiers

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl FormatArgs for ()

Source

fn format_at<W: WriteBuffer>( &self, _index: usize, _w: &mut W, _spec: &FormatSpec, ) -> AzUtilResult<()>

Source

impl<T0: FDisplay> FormatArgs for (T0,)

Source

fn format_at<W: WriteBuffer>( &self, index: usize, w: &mut W, spec: &FormatSpec, ) -> AzUtilResult<()>

Source

impl<T0: FDisplay, T1: FDisplay> FormatArgs for (T0, T1)

Source

fn format_at<W: WriteBuffer>( &self, index: usize, w: &mut W, spec: &FormatSpec, ) -> AzUtilResult<()>

Source

impl<T0: FDisplay, T1: FDisplay, T2: FDisplay> FormatArgs for (T0, T1, T2)

Source

fn format_at<W: WriteBuffer>( &self, index: usize, w: &mut W, spec: &FormatSpec, ) -> AzUtilResult<()>

Source

impl<T0: FDisplay, T1: FDisplay, T2: FDisplay, T3: FDisplay> FormatArgs for (T0, T1, T2, T3)

Source

fn format_at<W: WriteBuffer>( &self, index: usize, w: &mut W, spec: &FormatSpec, ) -> AzUtilResult<()>

Source

impl<T0: FDisplay, T1: FDisplay, T2: FDisplay, T3: FDisplay, T4: FDisplay> FormatArgs for (T0, T1, T2, T3, T4)

Source

fn format_at<W: WriteBuffer>( &self, index: usize, w: &mut W, spec: &FormatSpec, ) -> AzUtilResult<()>

Source

impl<T0: FDisplay, T1: FDisplay, T2: FDisplay, T3: FDisplay, T4: FDisplay, T5: FDisplay> FormatArgs for (T0, T1, T2, T3, T4, T5)

Source

fn format_at<W: WriteBuffer>( &self, index: usize, w: &mut W, spec: &FormatSpec, ) -> AzUtilResult<()>

Implementors