Module psearch

Module psearch 

Extendable pattern search utilities over byte slices.

Provides building blocks for scanning memory regions with optional wildcard support

Structs

BasePattern
A basic byte pattern
MaskedPattern
A byte pattern with a wildcard mask In the mask, 1 means the byte must match, and 0 means it’s a wildcard.
SearchAll
Iterator over all matches in a region. Produced by Searcher::search_all
Searcher
A Generic searcher for any type that implements the Pattern trait

Traits

Pattern
A trait for types that can be searched for within a byte slice