Searcher

Struct Searcher 

pub struct Searcher<P: Pattern> { /* private fields */ }
A Generic searcher for any type that implements the Pattern trait

Implementations

Source

impl<P: Pattern> Searcher<P>

pub fn new(pattern: P) -> AzUtilResult<Self>

Creates a new pattern searcher object

pub fn search(&mut self, region: &[u8]) -> Option<usize>

Searches a given memory region for the first occurance of the pattern

pub fn search_all<'searcher, 'region>( &'searcher mut self, region: &'region [u8], ) -> SearchAll<'searcher, 'region, P>

Returns an iterator over all non-overlapping matches of the pattern in the region.

pub fn result(&self) -> Option<usize>

Gets the last found result, if any.

pub fn reset(&mut self)

Resets the context result for reuse with the same pattern.

pub fn pattern(&self) -> &P

Returns a reference to the underlying pattern.

pub fn set_pattern(&mut self, pattern: P)

Resets the searcher and sets a new pattern