Minimal data encoding/decoding helpers.
Structs
- Decoder
- A generic decoder that deserializes primitive types and collections from a byte slice.
- Encoder
- A generic encoder that serializes different primitive types and collections into a byte buffer.
Traits
- Codec
- Trait for encoding and decoding data types to and from byte buffers.