pub trait FormatArgs {
// Required method
fn format_at<W: WriteBuffer>(
&self,
index: usize,
w: &mut W,
spec: &FormatSpec,
) -> AzUtilResult<()>;
}Expand description
Argument formatting trait
The trait requires each implementor to implement the FormatArgs::format_at function
Required Methods
Sourcefn format_at<W: WriteBuffer>(
&self,
index: usize,
w: &mut W,
spec: &FormatSpec,
) -> AzUtilResult<()>
fn format_at<W: WriteBuffer>( &self, index: usize, w: &mut W, spec: &FormatSpec, ) -> AzUtilResult<()>
Argument formatting function
Expects a writable buffer that implements the WriteBuffer trait, an index for specifying where to place the formatted value,
and a FormatSpec object to allow the usage of the additional format specifiers
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.