Extendable pattern search utilities over byte slices.
Provides building blocks for scanning memory regions with optional wildcard support
Structs
- Base
Pattern - A basic byte pattern
- Masked
Pattern - A byte pattern with a wildcard mask
In the mask,
1means the byte must match, and0means it’s a wildcard. - Search
All - Iterator over all matches in a region. Produced by
Searcher::search_all - Searcher
- A Generic searcher for any type that implements the
Patterntrait
Traits
- Pattern
- A trait for types that can be searched for within a byte slice